@@ -1,6 +1,6 @@
 # coding=utf-8
 # pynput
-# Copyright (C) 2015-2019 Moses Palmér
+# Copyright (C) 2015-2020 Moses Palmér
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -24,6 +24,13 @@ The keyboard implementation for *Xorg*.
 # pylint: disable=R0903
 # We implement stubs
 
+# pylint: disable=W0611
+try:
+    import pynput._util.xorg
+except Exception as e:
+    raise ImportError('failed to acquire X connection: {}'.format(str(e)), e)
+# pylint: enable=W0611
+
 import enum
 import threading
 
@@ -39,6 +46,7 @@ from pynput._util import NotifierMixin
 from pynput._util.xorg import (
     alt_mask,
     alt_gr_mask,
+    char_to_keysym,
     display_manager,
     index_to_shift,
     keyboard_mapping,
@@ -57,7 +65,7 @@ from . import _base
 
 class KeyCode(_base.KeyCode):
     _PLATFORM_EXTENSIONS = (
-        # The symbol named for this key
+        # The symbol name for this key
         '_symbol',
     )
 
@@ -433,10 +441,17 @@ class Controller(NotifierMixin, _base.Controller):
         :return: a keysym if found
         :rtype: int or None
         """
+        # If the key code already has a VK, simply return it
+        if key.vk is not None:
+            return key.vk
+
+        # If the character has no associated symbol, we try to map the
+        # character to a keysym
         symbol = CHARS.get(key.char, None)
         if symbol is None:
-            return None
+            return char_to_keysym(key.char)
 
+        # Otherwise we attempt to convert the symbol to a keysym
         # pylint: disable=W0702; we want to ignore errors
         try:
             return symbol_to_keysym(symbol)
